@@ -1,7 +1,19 @@
 sum_scores <- suppressMessages(
-  summarise_scores(scores, by = c("model", "target_type"))
+  summarise_scores(scores_quantile, by = c("model", "target_type"))
 )
 
+test_that("plot_wis() throws an error if WIS components are missing", {
+  ex_score <- na.omit(example_quantile) %>%
+    as_forecast_quantile() %>%
+    score(metrics = get_metrics(., select = "wis"))
+
+  expect_error(
+    plot_wis(ex_score),
+    "Columns 'overprediction', 'underprediction', 'dispersion' not found in data."
+  )
+})
+
+
 test_that("plot_wis() works as expected with relative contributions", {
   p <- plot_wis(sum_scores,
     x = "model",
@@ -34,4 +46,4 @@ test_that("plot_wis() works as expected when flipped", {
   expect_s3_class(p, "ggplot")
   skip_on_cran()
   vdiffr::expect_doppelganger("plot_wis_flip", p)
-})
\ No newline at end of file
+})
